@@ -15,9 +15,6 @@ import os
 import time
 import sys
   
-def profile(p):
-  global profile
-  p = profile
 
 def upload(filename):
   try:
@@ -27,14 +24,10 @@ def upload(filename):
   except FileNotFoundError as e:
     print(f"[ ERROR ] : {e}")
     return f"[ ERROR ] : {e}"
-  if profile is not None:
-    response = requests.post('https://starfiles.co/api/upload/upload_file?profile={profile}', files=files)
-  else:
-    response = requests.post('https://starfiles.co/api/upload/upload_file', files=files)
-    pass
+  response = requests.post('https://api.starfiles.co/upload/upload_file', files=files)
   api = json.loads(response.text)
   file = api['file']
-  link = f"https://starfiles.co/api/direct/{file}"
+  link = f"https://api.starfiles.co/direct/{file}"
   size = round(int(os.path.getsize(filename)) / 1000000, 2)
   name = re.sub(r'^.*?/', '', filename)
   print("\n")
@@ -43,5 +36,5 @@ def upload(filename):
   print(f"Size: {size}mb")
   print(f"Download Link:\nRegular: https://starfiles.co/file/{file}\nDirect: {link}")
   if re.search("ipa$", filename):
-    print(f"Plist: https://starfiles.co/api/installipa/{file}\nInstall URL: itms-services://?action=download-manifest&url=https://starfiles.co/api/installipa/{file}")
-  return link
\ No newline at end of file
+    print(f"Plist: https://api.starfiles.co/installipa/{file}\nInstall URL: itms-services://?action=download-manifest&url=https://api.starfiles.co/installipa/{file}")
+  return link
